@@ -17,10 +17,13 @@ package MooseX::AttributeTree;
 # ABSTRACT: Inherit attribute values like HTML+CSS does
 #---------------------------------------------------------------------
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 use 5.008;
 
 
+# Verify Moose version, but don't import because we're a Role
+use Moose 2.0205 (); # bugfix for parameterized traits
+
 use MooseX::Role::Parameterized;
 
 use MooseX::AttributeTree::Accessor ();
@@ -91,9 +94,9 @@ MooseX::AttributeTree - Inherit attribute values like HTML+CSS does
 
 =head1 VERSION
 
-This document describes version 0.04 of
-MooseX::AttributeTree, released October 11, 2011
-as part of MooseX-AttributeTree version 0.04.
+This document describes version 0.05 of
+MooseX::AttributeTree, released October 5, 2013
+as part of MooseX-AttributeTree version 0.05.
 
 =head1 SYNOPSIS
 
@@ -246,10 +249,10 @@ call the predicate method of each ancestor.)
 
 Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
-Please report any bugs or feature requests to
-S<C<< <bug-MooseX-AttributeTree AT rt.cpan.org> >>>,
+Please report any bugs or feature requests
+to S<C<< <bug-MooseX-AttributeTree AT rt.cpan.org> >>>
 or through the web interface at
-L<http://rt.cpan.org/Public/Bug/Report.html?Queue=MooseX-AttributeTree>
+L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=MooseX-AttributeTree >>.
 
 You can follow or contribute to MooseX-AttributeTree's development at
 L<< http://github.com/madsen/moosex-attributetree >>.
@@ -262,7 +265,7 @@ L<http://www.mitsi.com>, who sponsored its development.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Christopher J. Madsen.
+This software is copyright (c) 2013 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
